//  $Id: font_test_screen.hpp 3265 2007-09-30 16:07:08Z grumbel $
//
//  Pingus - A free Lemmings clone
//  Copyright (C) 2007 Ingo Ruhnke <grumbel@gmx.de>
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#ifndef HEADER_FONT_TEST_SCREEN_HPP
#define HEADER_FONT_TEST_SCREEN_HPP

#include "screen/screen.hpp"
#include "font.hpp"

/** */
class FontTestScreen : public Screen
{
private:
  Font font;
  Font reference;
  float scrollx;
  float scrolly;
  bool  dark;
public:
  FontTestScreen(const Pathname& fontfile);

  bool draw(DrawingContext& gc);
  void update (const GameDelta& delta);

private:
  FontTestScreen (const FontTestScreen&);
  FontTestScreen& operator= (const FontTestScreen&);
};

#endif

/* EOF */
